==> ejc-budgetmanage-impl-3.0.0-20220325.144208-24-sources.jar: com/ejianc/business/change/bean/ChangequotadesignEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 限额设计表变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_budgetmanage_quotadesign")
public class ChangequotadesignEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="quotadesign_id")
    private java.lang.Long quotadesignId; // 限额设计表id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="cost_total")
    private java.math.BigDecimal costTotal; // 造价合计
    @TableField(value="labor_total")
    private java.math.BigDecimal laborTotal; // 人工费合计
    @TableField(value="material_total")
    private java.math.BigDecimal materialTotal; // 材料费合计
    @TableField(value="mechanical_total")
    private java.math.BigDecimal mechanicalTotal; // 机械费合计
    @TableField(value="management_total")
    private java.math.BigDecimal managementTotal; // 企业管理费合计
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费合计
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金合计
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changequotadesigndetailService", pidName = "changeMid")
    private List<ChangequotadesigndetailEntity> quotadesigndetailEntities = new ArrayList<>(); // 限额设计表变更子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 限额设计表id
     */
    public java.lang.Long getQuotadesignId() {
        return quotadesignId;
    }

    /**
     * 限额设计表id
     */
    public void setQuotadesignId(java.lang.Long quotadesignId) {
        this.quotadesignId = quotadesignId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 人工费合计
     */
    public java.math.BigDecimal getLaborTotal() {
        return laborTotal;
    }

    /**
     * 人工费合计
     */
    public void setLaborTotal(java.math.BigDecimal laborTotal) {
        this.laborTotal = laborTotal;
    }
    /**
     * 材料费合计
     */
    public java.math.BigDecimal getMaterialTotal() {
        return materialTotal;
    }

    /**
     * 材料费合计
     */
    public void setMaterialTotal(java.math.BigDecimal materialTotal) {
        this.materialTotal = materialTotal;
    }
    /**
     * 机械费合计
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费合计
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费合计
     */
    public java.math.BigDecimal getManagementTotal() {
        return managementTotal;
    }

    /**
     * 企业管理费合计
     */
    public void setManagementTotal(java.math.BigDecimal managementTotal) {
        this.managementTotal = managementTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    
    /**
     * 限额设计表变更子表
     */
    public List<ChangequotadesigndetailEntity> getQuotadesigndetailEntities() {
        return quotadesigndetailEntities;
    }

    /**
     * 限额设计表变更子表
     */
    public void setQuotadesigndetailEntities(List<ChangequotadesigndetailEntity> quotadesigndetailEntities) {
        this.quotadesigndetailEntities = quotadesigndetailEntities;
    }


}

==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/change/bean/ChangequotadesignEntity.java <==
package com.ejianc.business.change.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 限额设计表变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_budgetmanage_quotadesign")
public class ChangequotadesignEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="quotadesign_id")
    private java.lang.Long quotadesignId; // 限额设计表id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="cost_total")
    private java.math.BigDecimal costTotal; // 造价合计
    @TableField(value="labor_total")
    private java.math.BigDecimal laborTotal; // 人工费合计
    @TableField(value="material_total")
    private java.math.BigDecimal materialTotal; // 材料费合计
    @TableField(value="mechanical_total")
    private java.math.BigDecimal mechanicalTotal; // 机械费合计
    @TableField(value="management_total")
    private java.math.BigDecimal managementTotal; // 企业管理费合计
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费合计
    @TableField(value="profits_total")
    private java.math.BigDecimal profitsTotal; // 利润合计
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金合计
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changequotadesigndetailService", pidName = "changeMid")
    private List<ChangequotadesigndetailEntity> quotadesigndetailEntities = new ArrayList<>(); // 限额设计表变更子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 限额设计表id
     */
    public java.lang.Long getQuotadesignId() {
        return quotadesignId;
    }

    /**
     * 限额设计表id
     */
    public void setQuotadesignId(java.lang.Long quotadesignId) {
        this.quotadesignId = quotadesignId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 人工费合计
     */
    public java.math.BigDecimal getLaborTotal() {
        return laborTotal;
    }

    /**
     * 人工费合计
     */
    public void setLaborTotal(java.math.BigDecimal laborTotal) {
        this.laborTotal = laborTotal;
    }
    /**
     * 材料费合计
     */
    public java.math.BigDecimal getMaterialTotal() {
        return materialTotal;
    }

    /**
     * 材料费合计
     */
    public void setMaterialTotal(java.math.BigDecimal materialTotal) {
        this.materialTotal = materialTotal;
    }
    /**
     * 机械费合计
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费合计
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费合计
     */
    public java.math.BigDecimal getManagementTotal() {
        return managementTotal;
    }

    /**
     * 企业管理费合计
     */
    public void setManagementTotal(java.math.BigDecimal managementTotal) {
        this.managementTotal = managementTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }

    public BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    public void setProfitsTotal(BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }

    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    
    /**
     * 限额设计表变更子表
     */
    public List<ChangequotadesigndetailEntity> getQuotadesigndetailEntities() {
        return quotadesigndetailEntities;
    }

    /**
     * 限额设计表变更子表
     */
    public void setQuotadesigndetailEntities(List<ChangequotadesigndetailEntity> quotadesigndetailEntities) {
        this.quotadesigndetailEntities = quotadesigndetailEntities;
    }


}
